echo "Installing package dependencies inside docker:"
echo ""
pyemr python --env venv

